@@ -102,12 +102,13 @@ def image(surface, node):
         surface.context.clip()
 
     # Paint raster image
+    opacity = float(node.get('opacity', 1))
     surface.context.save()
     surface.context.translate(x, y)
     surface.context.scale(scale_x, scale_y)
     surface.context.translate(translate_x, translate_y)
     surface.context.set_source(image_surface.pattern)
-    surface.context.paint()
+    surface.context.paint_with_alpha(opacity)
     surface.context.restore()
 
 
